import { Translation } from "@/src/utils/Translation";

export const formatearFechaHora = (fechaHora: string) => {
    const { trans } = Translation();
    // Convertir la fecha y hora a hora local de Colombia (-5)
    const fechaLocalColombia = new Date(fechaHora + ' GMT-0500');

    // Obtener la fecha actual en hora local de Colombia
    const hoy = new Date();
    hoy.setHours(hoy.getHours() - 5);

    // Calcular la diferencia en días entre la fecha actual y la fecha proporcionada
    const diferenciaDias = (hoy.getTime() - fechaLocalColombia.getTime()) / (1000 * 60 * 60 * 24);

    // Formatear la fecha según las condiciones
    if (diferenciaDias < 1 && hoy.getDate() === fechaLocalColombia.getDate()) {
        // Si la fecha es de hoy, mostrar solo la hora
        return fechaLocalColombia.toLocaleTimeString('es-CO', { hour12: true, hour: '2-digit', minute: '2-digit' });
    } else if (diferenciaDias < 2 && hoy.getDate() - fechaLocalColombia.getDate() === 1) {
        // Si la fecha es de ayer, mostrar "ayer"
        return trans('yesterday');
    } else if (diferenciaDias < 7) {
        // Si la fecha es de hace 7 días, mostrar el día de la semana        
        const diasSemana = [trans('sunday'), trans('monday'), trans('tuesday'), trans('wednesday'), trans('thursday'), trans('friday'), trans('saturday')];
        return diasSemana[fechaLocalColombia.getDay()];
    } else {
        // Si la fecha es después de 7 días, mostrar la fecha
        const options = { month: 'short', day: 'numeric' };
        const fechaFormateada = fechaLocalColombia.toLocaleDateString('es-CO', options as Intl.DateTimeFormatOptions);
        if (hoy.getFullYear() === fechaLocalColombia.getFullYear()) {
            // Si la fecha es este año, mostrar solo mes y día
            return fechaFormateada;
        } else {
            // Si la fecha es otro año, mostrar mes, día y año
            return fechaFormateada + ' ' + fechaLocalColombia.getFullYear();
        }
    }
}